# Generated by roxygen2: do not edit by hand

S3method(plot,detector_result)
S3method(plot,udld_report)
S3method(run_detector,temporal_detector)
S3method(run_detector,train_test_detector)
export("%||%")
export(compile_report)
export(format_detector_name)
export(generate_diagnostic_plots)
export(generate_recommendations)
export(get_detector_info)
export(leakr_audit)
export(leakr_create_snapshot)
export(leakr_export_data)
export(leakr_from_caret)
export(leakr_from_mlr3)
export(leakr_from_tidymodels)
export(leakr_import)
export(leakr_list_snapshots)
export(leakr_load_snapshot)
export(leakr_plot)
export(leakr_quick_import)
export(leakr_summarise)
export(list_registered_detectors)
export(new_temporal_detector)
export(new_train_test_detector)
export(prepare_audit_data)
export(register_detector)
export(run_detector)
export(run_detectors)
export(stratified_sample)
export(validate_and_preprocess_data)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_brewer)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,modifyList)
importFrom(utils,read.csv)
importFrom(utils,read.delim)
importFrom(utils,str)
importFrom(utils,write.csv)
